/*
    The source code contained within this file is protected under the
    laws of the United States of America and by International Treaty.
    Unless otherwise noted, the source contained herein is:

    Copyright (c)1990-1994 BecknerVision Inc - No Rights Reserved

    Written by John Wm Beckner
    BecknerVision Inc

        ** THIS FILE IS PUBLIC DOMAIN **

        ** Use of this code is at your own risk, absolutely no guarantees
        ** are made to its usefulness  - you must determine for yourself if
        ** this code is of any use to you.  If you do not agree with this, do
        ** not use this code. **
*/

#include "beckner.inc"

////////////////
////////////////
//
// Purpose:
//    Interactive function to SET FILTER
//
// Syntax:
//    fCondition([<cAlias>], [<cFilter>]) -> NIL
//
// Formal Arguments: (2)
//    Name        Description
//    ___________ ____________
//    cAlias      Work area alias [current work area]
//    cFilter     Filter condition in string format [""]
//
// Returns:
//    NIL
//
// Examples:
//    #include "beckner.inc"
//    FUNCTION TestIt()
//       CreateTest()
//       fCondition("Test", "Name='A'")
//       fBrowse()         /* only one record is in the browse table */
//       CLOSE Test
//    ENDFUNCTION
//
//    #include "alias.ch"
//    STATIC FUNCTION CreateTest()
//       fCreateDbf("Test/Name/C/32/Balance/N/12/2/Date/D/Over21/L/Notes/M")
//       USE Test NEW EXCLUSIVE
//       ADDRECORD ALIAS Test
//       Test->Name    := "Abbott, Jake"
//       Test->Balance := 0.00
//       Test->Date    := CtoD("9/26/94")
//       Test->Over21  := .y.
//       Test->Notes   := ""
//       ADDRECORD ALIAS Test
//       Test->Name    := "Beckner, John Wm"
//       Test->Balance := 15000.00
//       Test->Date    := CtoD("9/26/94")
//       Test->Over21  := .y.
//       Test->Notes   := "These are notes!"
//       ADDRECORD ALIAS Test
//       Test->Name    := "Beckner, Elizabeth Anne"
//       Test->Balance := 0.58
//       Test->Date    := CtoD("12/18/96")
//       Test->Over21  := .n.
//       Test->Notes   := ""
//       ADDRECORD ALIAS Test
//       Test->Name    := "Beckner, Joseph Alan"
//       Test->Balance := 1.68
//       Test->Date    := CtoD("6/10/98")
//       Test->Over21  := .n.
//       Test->Notes   := "These are too!"
//       ADDRECORD ALIAS Test
//       Test->Name    := "Zumundi, Beavis"
//       Test->Balance := 123.45
//       Test->Date    := CtoD("")
//       Test->Over21  := .y.
//       Test->Notes   := ""
//       GO TOP
//    ENDFUNCTION

//
// Files:
//    (cAlias).dbf
//
// Description:
//    If <cFilter> is a non-empty string, then the string is evaluated and
//    must return a logical value.  If <cFilter> is not specified or is
//    empty, then the operator is prompted for the filter condition.  It is
//    set for the work area specified, which defaults to the current work
//    area.
//
// Category:
//    File Function
//
// Revisions:
//    01/26/94 Added comment blocks
//
////////////////
////////////////

FUNCTION fCondition(cAlias, c_str)
   LOCAL nWorkArea, cTemp
   IF pCount()<2
      cTemp=Space(250)
   ENDIF
   IF pcount()=0
      cAlias=Alias()
   ENDIF
   nWorkArea=Select()
   SELECT (Select(cAlias))
   IF Empty(cTemp)
      cTemp=vAnswer('Enter conditional:', 50)
   ENDIF
   SET FILTER TO &(cTemp)
   SELECT (nWorkArea)
ENDFUNCTION
